/// <reference types="node" />
import fsMod from 'node:fs';
import type { AstroInlineConfig, AstroSettings } from '../../@types/astro';
import { type LogOptions } from '../logger/core.js';
export type ProcessExit = 0 | 1;
export type SyncOptions = {
    /**
     * Only used for testing
     * @internal
     */
    fs?: typeof fsMod;
};
export type SyncInternalOptions = SyncOptions & {
    logging: LogOptions;
};
export declare function sync(inlineConfig: AstroInlineConfig, options?: SyncOptions): Promise<ProcessExit>;
/**
 * Generate content collection types, and then returns the process exit signal.
 *
 * A non-zero process signal is emitted in case there's an error while generating content collection types.
 *
 * This should only be used when the callee already has an `AstroSetting`, otherwise use `sync()` instead.
 * @internal
 *
 * @param {SyncOptions} options
 * @param {AstroSettings} settings Astro settings
 * @param {typeof fsMod} options.fs The file system
 * @param {LogOptions} options.logging Logging options
 * @return {Promise<ProcessExit>}
 */
export declare function syncInternal(settings: AstroSettings, { logging, fs }: SyncInternalOptions): Promise<ProcessExit>;
